
From: Jan Kara <jack@suse.cz>

Fix a bug in list scanning that can cause us to skip the last buffer on the
checkpoint list (and hence fail to do any progress under some rather
unfavorable conditions).

The problem is we first do jh=next_jh and then test

	} while (jh!=last_jh);

Hence we skip the last buffer on the list (if it was not the only buffer on
the list).  As we already do jh=next_jh; in the beginning of the loop we
are safe to just remove the assignment in the end.  It can happen that 'jh'
will be freed at the point we test jh != last_jh but that does not matter
as we never *dereference* the pointer.

Signed-off-by: Jan Kara <jack@suse.cz>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 fs/jbd/checkpoint.c |    1 -
 1 files changed, 1 deletion(-)

diff -puN fs/jbd/checkpoint.c~ext3-fix-list-scanning-in-__cleanup_transaction fs/jbd/checkpoint.c
--- 25/fs/jbd/checkpoint.c~ext3-fix-list-scanning-in-__cleanup_transaction	2005-06-01 00:57:20.000000000 -0700
+++ 25-akpm/fs/jbd/checkpoint.c	2005-06-01 00:57:20.000000000 -0700
@@ -188,7 +188,6 @@ static int __cleanup_transaction(journal
 		} else {
 			jbd_unlock_bh_state(bh);
 		}
-		jh = next_jh;
 	} while (jh != last_jh);
 
 	return ret;
_
